@@ -23,7 +23,7 @@ class TestMovie(unittest.TestCase):
     @vcr.use_cassette(FIXTURES_DIR + '/vcr_cassettes/movie.yaml')
     def setUp(self):
         self.bom = BOM()
-        self.movies = self.bom.daily_chart()
+        self.movies = self.bom.get_chart()
         self.test_movie = self.movies.next() # get the first movie for testing
 
     def test_movie(self):
